#! /bin/bash
CONFIG="bcfy/bcfy-config.json"

###########################################################
# DO NOT CHANGE ANYTHING BELOW THIS LINE !!!
###########################################################
APIKEY="$( jq -r '.apiKey' "${CONFIG}" )"
FFMPEG_PATH="$( jq -r '.ffmpeg_path' "${CONFIG}" )"
FFMPEG_PATH=$(eval echo $FFMPEG_PATH)
DELETEFILES="$( jq -r '.deleteFiles' "${CONFIG}" )"
systemId="${1:-0}"
basename="${2%.*}"

if [ ! -f "${FFMPEG_PATH}/ffmpeg" ]; then
        echo "|============================================================================"
	echo "| *** !! FFMPEG Binary Not Found. Canceling Upload And Exiting..."
        echo "|============================================================================"
	exit
fi
if [ ! -f "${FFMPEG_PATH}/ffprobe" ]; then
        echo "|============================================================================"
	echo "| *** !! FFProbe Binary Not Found. Canceling Upload And Exiting..."
        echo "|============================================================================"
	exit
fi


nice -n 19 ${FFMPEG_PATH}/ffmpeg -i "${basename}.wav"  -c:a libfdk_aac -b:a 32k -cutoff 18000 "${basename}.m4a" > /dev/null 2>&1
duration=$(${FFMPEG_PATH}/ffprobe -v error -show_entries format=duration -of default=noprint_wrappers=1:nokey=1 "${basename}.m4a")
echo "BCFY UPLOAD: SystemId: ${systemId} | basename: ${basename} | duration: $duration"

serverResponse=$(curl -s https://api.broadcastify.com/call-upload -F "callDuration=${duration}" -F "filename=${basename}.m4a" -F "apiKey=${APIKEY}" -F "metadata=@${basename}.json;type=application/json" -F "systemId=${systemId}")

serverResponseArray=($serverResponse)
respCode=${serverResponseArray[0]}
uploadURL=${serverResponseArray[1]}
#echo "UPLOAD URL: ${serverResponse[0]}"
if [ ${respCode} == "0" ];
then
        echo "|============================================================================"
	echo "| BCFY API Response: ${respCode} (Good Response)"
        echo "|============================================================================"
        curlResp=$(curl --write-out %{http_code} --silent --output /dev/null -X PUT -H "Content-Type: audio/aac" -T ${basename}.m4a "${uploadURL}")
        echo "|============================================================================"
        echo "| BCFY Upload Response: ${curlResp} ${basename}.m4a"
        echo "|============================================================================"
	if [ ${DELETEFILES} == "1" ]; then
        	rm -f ${basename}.*
	fi
else
        echo "|============================================================================"
	echo "| *** !! BCFY API Response: ${respCode} ${uploadURL}"
        echo "|============================================================================"
fi
